@@ -14,7 +14,7 @@ from email.mime.text import MIMEText
 from email.header import Header
 
 
-__version__ ="0.0.2"
+__version__ ="0.0.3"
 
 #my exceptions
 class Error(Exception):
@@ -143,7 +143,7 @@ class MailSender:
                 encoders.encode_base64(filecontent)
 
                # Set the filename parameter
-            filecontent.add_header('Content-Disposition', 'attachment', filename=filePath)
+            filecontent.add_header('Content-Disposition', 'attachment', filename=os.path.basename(filePath))
             self.msg.attach(filecontent)
         else:
             raise Exception("the attached file is not existed")
